@@ -117,7 +117,6 @@ def generate_database():
     print("OK")
 
     attributes_dict, possible_values = mimic.infer_attributes()
-
     unused_attributes = [  # (table_name, attribute_name)
         ("d_items", "dbsource"),
         ("icustays", "dbsource"),
@@ -164,7 +163,7 @@ def generate_database():
             ("row_id", Attribute(DigitIDAttr)),
             (
                 "careunit",
-                Attribute(FieldAttr, possible_values=possible_values["services"]["curr_service"], ),
+                Attribute(FieldAttr, possible_values=possible_values["services"]["curr_service"],),
             ),
         ],
         "caregivers": [
@@ -210,7 +209,7 @@ def generate_database():
                         RelativeFloatAttr, min_val=float(min_val), max_val=float(max_val),
                     )
                 elif attr_type == "bool":
-                    curr_attributes[attr] = Attribute(BoolAttr, proba_true=float(attr_params), )
+                    curr_attributes[attr] = Attribute(BoolAttr, proba_true=float(attr_params),)
                 elif attr_type == "double_digit_id":
                     curr_attributes[attr] = Attribute(DoubleDigitIDAttr, length=int(attr_params))
                 elif attr_type == "composed_digit_id-":
@@ -249,7 +248,7 @@ def generate_database():
 
     relations = {
         "hadm_id": {
-            "parents": [("admissions", "hadm_id"), ],
+            "parents": [("admissions", "hadm_id"),],
             "children": [
                 ("chartevents", "hadm_id", (1, 2)),
                 # ('datetimeevents', 'hadm_id', (1, 2)),
@@ -257,7 +256,7 @@ def generate_database():
                 ("drgcodes", "hadm_id", (1, 2)),
                 ("icustays", "hadm_id", (1, 2)),
                 ("procedures_icd", "hadm_id", (1, 2)),
-                ("services", "hadm_id", (1, 2)),
+                ("services", "hadm_id", (1, 1)),
                 ("documents", "hadm_id", (1, 2)),
                 ("transfers", "hadm_id", (1, 2)),
                 ("prescriptions", "hadm_id", (1, 2)),
@@ -266,7 +265,7 @@ def generate_database():
             ],
         },
         "subject_id": {
-            "parents": [("patients", "subject_id"), ],
+            "parents": [("patients", "subject_id"),],
             "children": [
                 ("admissions", "subject_id", (1, 2)),
                 ("chartevents", "subject_id", (1, 2)),
@@ -275,7 +274,7 @@ def generate_database():
                 ("drgcodes", "subject_id", (1, 2)),
                 ("icustays", "subject_id", (1, 2)),
                 ("procedures_icd", "subject_id", (1, 2)),
-                ("services", "subject_id", (1, 2)),
+                ("services", "subject_id", (1, 1)),
                 ("transfers", "subject_id", (1, 2)),
                 ("prescriptions", "subject_id", (1, 2)),
                 ("labevents", "subject_id", (1, 2)),
@@ -284,7 +283,7 @@ def generate_database():
             ],
         },
         "cgid": {
-            "parents": [("caregivers", "cgid"), ],
+            "parents": [("caregivers", "cgid"),],
             "children": [
                 ("chartevents", "cgid", (1, 2)),
                 # ('datetimeevents', 'cgid', (1, 2)),
@@ -292,7 +291,7 @@ def generate_database():
             ],
         },
         "icustay_id": {
-            "parents": [("icustays", "icustay_id"), ],
+            "parents": [("icustays", "icustay_id"),],
             "children": [
                 ("chartevents", "icustay_id", (0, 2)),
                 # ('datetimeevents', 'icustay_id', (1, 2)),
@@ -301,7 +300,7 @@ def generate_database():
             ],
         },
         "itemid": {
-            "parents": [("d_items", "itemid"), ],
+            "parents": [("d_items", "itemid"),],
             "children": [
                 ("chartevents", "itemid", (1, 2)),
                 # ('datetimeevents', 'itemid', (1, 2)),
@@ -312,12 +311,12 @@ def generate_database():
             ],
         },
         "icd9_code_diagnoses": {
-            "parents": [("d_icd_diagnoses", "icd9_code"), ],
-            "children": [("diagnoses_icd", "icd9_code", (1, 2)), ],
+            "parents": [("d_icd_diagnoses", "icd9_code"),],
+            "children": [("diagnoses_icd", "icd9_code", (1, 2)),],
         },
         "icd9_code_procedures": {
-            "parents": [("d_icd_procedures", "icd9_code"), ],
-            "children": [("procedures_icd", "icd9_code", (1, 2)), ],
+            "parents": [("d_icd_procedures", "icd9_code"),],
+            "children": [("procedures_icd", "icd9_code", (1, 2)),],
         },
         "service": {
             "parents": [("hospit_services", "careunit")],
@@ -400,12 +399,12 @@ def generate_pdf():
                 row["patient_birth_date"], "%Y-%m-%d %H:%M:%S"
             )
             patient_age = (
-                    doc_date.year
-                    - patient_birth_date.year
-                    - (
-                            (doc_date.month, doc_date.day)
-                            < (patient_birth_date.month, patient_birth_date.day)
-                    )
+                doc_date.year
+                - patient_birth_date.year
+                - (
+                    (doc_date.month, doc_date.day)
+                    < (patient_birth_date.month, patient_birth_date.day)
+                )
             )
             medication_result = connection.execute(
                 f"""SELECT
@@ -434,7 +433,10 @@ def generate_pdf():
                 row["path"],
                 locale=args.locale,
                 doc_attributes={"date": doc_date.strftime("%d/%m/%Y")},
-                doctor={"first_name": row["doctor_first_name"], "last_name": row["doctor_last_name"], },
+                doctor={
+                    "first_name": row["doctor_first_name"],
+                    "last_name": row["doctor_last_name"],
+                },
                 patient={
                     "first_name": row["patient_first_name"],
                     "last_name": row["patient_last_name"],
@@ -447,7 +449,10 @@ def generate_pdf():
             cr_generator(
                 row["path"],
                 locale=args.locale,
-                doctor={"first_name": row["doctor_first_name"], "last_name": row["doctor_last_name"], },
+                doctor={
+                    "first_name": row["doctor_first_name"],
+                    "last_name": row["doctor_last_name"],
+                },
                 patient={
                     "first_name": row["patient_first_name"],
                     "last_name": row["patient_last_name"],
@@ -456,12 +461,14 @@ def generate_pdf():
                 },
                 hospitalization={
                     "reason": row["diagnoses_st"],
-                    "hospitalization": row["diagnoses_lt"]
+                    "hospitalization": row["diagnoses_lt"],
                 },
                 date={
                     "last_date": doc_date.strftime("%d/%m/%Y"),
-                    "first_date": (doc_date - datetime.timedelta(days=randint(0, 16))).strftime("%d/%m/%Y"),
-                    "birth_date": patient_birth_date
+                    "first_date": (doc_date - datetime.timedelta(days=randint(0, 16))).strftime(
+                        "%d/%m/%Y"
+                    ),
+                    "birth_date": patient_birth_date,
                 },
                 medication=medication,
-            )
\ No newline at end of file
+            )
