@@ -146,6 +146,19 @@ class DataBaseRandomGenerator:
                     )
                     shuffle(current_possible_values)
                     self._possible_values[table_name][attr_name] = current_possible_values
+            elif rel_type == (1, 1):
+                if length == 0:
+                    current_possible_values = possible_values
+                    shuffle(current_possible_values)
+                    self._possible_values[table_name][attr_name] = current_possible_values
+                    self._possible_length[table_name] = len(current_possible_values)
+                else:
+                    assert (
+                        length >= length_possible_values
+                    ), f"Too many values to fit in attribute {attr_name} from table {table_name}."
+                    current_possible_values = possible_values
+                    shuffle(current_possible_values)
+                    self._possible_values[table_name][attr_name] = current_possible_values
 
     def random_generation(self, min_rows=100, max_card=5, missing_rate=0.1):
 
