@@ -179,7 +179,7 @@ def add_block(pdf, txt, align="L"):
     Keyword Arguments:
         align {str} -- text alignment : the possible values are "L", "C" and "R" (default: {"L"})
     """
-
+    txt = unidecode(txt)
     for row in txt.split("\n"):
         pdf.cell(200, 5, txt=row, ln=1, align=align)
 
@@ -194,7 +194,7 @@ def signature(name):
         str -- signature
     """
 
-    name_list = unidecode(name).split(" ")
+    name_list = name.split(" ")
     sign = ""
     for w in name_list[:-1]:
         if randint(0, 1):
@@ -369,9 +369,10 @@ Centre Médical de {field_group_values["medical_centre"]["city"]}
 
     # Signature
 
-    pdf.add_font("Signature", "", choice(SIGNATURE_FONTS), uni=True)
     font_size = randint(20, 40)
-    pdf.set_font("Signature", size=font_size)
+    pdf.set_font(font, "I", size=font_size)
+    # pdf.add_font("Signature", "", choice(SIGNATURE_FONTS), uni=True)
+    # pdf.set_font("Signature", size=font_size)
 
     txt = f"""
 
@@ -586,10 +587,10 @@ Traitement de sortie
         {field_group_values["medication"][i]["name"]} {field_group_values["medication"][i]["dose"]} mg, {field_group_values["medication"][i]["poso_qty"]} {field_group_values["medication"][i]["poso_type"]} {field_group_values["medication"][i]["poso_freq"]} {field_group_values["medication"][i]["poso_duration"]}"""
     add_block(pdf, txt, align="L")
     # Signature
-
-    pdf.add_font("Signature", "", choice(SIGNATURE_FONTS), uni=True)
     font_size = randint(20, 40)
-    pdf.set_font("Signature", size=font_size)
+    pdf.set_font(font, "I", size=font_size)
+    # pdf.add_font("Signature", "", choice(SIGNATURE_FONTS), uni=True)
+    # pdf.set_font("Signature", size=font_size)
 
     txt = f"""
     {signature(field_group_values["doctor"]['last_name'])}          {int((40 - font_size) / 20) * randint(0, 20) * ' '}
@@ -609,14 +610,14 @@ def get_id():
     return str(randint(1000, 100000)).zfill(6)
 
 
-def generate(nb, output_path):
+def generate(nb, output_path, locale="fr_FR"):
     """Generate several fake medical prescriptions
 
     Arguments:
         nb {int} -- number or fake medical prescriptions to generate
         output_path {str} -- folder to store the fake medical prescriptions in
     """
-
+    fake = Factory.create(locale)
     output_path = Path(output_path)
 
     link = pd.DataFrame(
